@@ -1,3 +1,5 @@
+#!/usr/bin/env python
+
 import sys
 
 from lazygal import pyexiv2api as pyexiv2
@@ -5,7 +7,7 @@ from lazygal import pyexiv2api as pyexiv2
 fn = sys.argv[1]
 comment = sys.argv[2]
 
-im = pyexiv2.ImageMetadata(fn)
+im = pyexiv2.ImageMetadata(fn.decode(sys.getfilesystemencoding()))
 im.read()
 
 # Assume comment is in utf-8, more encoding processing example using
