@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
-# Lazygal, a lazy satic web gallery generator.
-# Copyright (C) 2007-2011 Alexandre Rossi <alexandre.rossi@gmail.com>
+# Lazygal, a lazy static web gallery generator.
+# Copyright (C) 2007-2012 Alexandre Rossi <alexandre.rossi@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -37,6 +37,7 @@ locale.setlocale(locale.LC_ALL, '')
 import lazygal
 from lazygal.generators import Album
 import lazygal.config
+import lazygal.eyecandy
 
 
 usage = _("usage: %prog [options] albumdir")
@@ -69,6 +70,10 @@ parser.add_option("", "--template-vars",
                   action="store", type="string",
                   dest="tpl_vars",
                   help=_("Common variables to load all templates with."))
+parser.add_option("-f", "--force-gen-pages",
+                  action="store_true",
+                  dest="force_gen_pages",
+                  help=_("Force rebuild of all pages."))
 parser.add_option("", "--clean-destination",
                   action="store_true",
                   dest="clean_destination",
@@ -129,12 +134,21 @@ parser.add_option("", "--webalbum-pic-bg",
                   action="store", type="string",
                   dest="webalbumpic_bg",
                   help=_("Webalbum picture background color. Default is transparent, and implies the PNG format. Any other value, e.g. red, white, blue, uses JPEG."))
+parser.add_option("", "--webalbum-pic-type",
+                  action="store", type="choice",
+                  choices=lazygal.eyecandy.WEBALBUMPIC_TYPES.keys(),
+                  dest="webalbumpic_type",
+                  help=_("Webalbum picture type. Default is messy."))
 parser.add_option("", "--pic-sort-by",
                   action="store", metavar=_('ORDER'),
                   dest="pic_sort_by", help=_("Sort order for images in a folder: filename, mtime, or exif. Add ':reverse' to reverse the chosen order."))
 parser.add_option("", "--subgal-sort-by",
                   action="store", metavar=_('ORDER'),
                   dest="subgal_sort_by", help=_("Sort order for sub galleries in a folder: dirname or mtime. Add ':reverse' to reverse the chosen order."))
+parser.add_option("", "--keep-gps-data",
+                    action="store_true",
+                    dest="keep_gps",
+                    help=_("Do not remove GPS location tags from EXIF metadata. Mostly useful with holiday photos."))
 (options, args) = parser.parse_args()
 
 if options.show_version:
@@ -164,6 +178,8 @@ if options.check_all_dirs:
 if options.dest_dir is not None:
     cmdline_config.set('global', 'destdir',
                        options.dest_dir.decode(sys.getfilesystemencoding()))
+if options.force_gen_pages:
+    cmdline_config.set('global', 'force-gen-pages', 'Yes')
 if options.clean_destination:
     cmdline_config.set('global', 'clean-destination', 'Yes')
 if options.dir_flattening_depth is not None:
@@ -178,6 +194,8 @@ if options.default_style is not None:
     cmdline_config.set('webgal', 'default-style', options.default_style)
 if options.webalbumpic_bg is not None:
     cmdline_config.set('webgal', 'webalbumpic-bg', options.webalbumpic_bg)
+if options.webalbumpic_type is not None:
+    cmdline_config.set('webgal', 'webalbumpic-type', options.webalbumpic_type)
 if options.image_size is not None:
     cmdline_config.set('webgal', 'image-size', options.image_size)
 if options.thumbnail_size is not None:
@@ -187,7 +205,7 @@ if options.thumbs_per_page is not None:
 if options.pic_sort_by is not None:
     cmdline_config.set('webgal', 'sort-medias', options.pic_sort_by)
 if options.subgal_sort_by is not None:
-    cmdline_config.set('webgal', 'sort-subgals', options.pic_sort_by)
+    cmdline_config.set('webgal', 'sort-subgals', options.subgal_sort_by)
 if options.original:
     cmdline_config.set('webgal', 'original', 'Yes')
 if options.orig_base is not None:
@@ -204,6 +222,8 @@ if options.dirzip:
     cmdline_config.set('webgal', 'dirzip', 'Yes')
 if options.quality is not None:
     cmdline_config.set('webgal', 'jpeg-quality', options.quality)
+if options.keep_gps:
+    cmdline_config.set('webgal', 'keep-gps', 'Yes')
 
 if options.tpl_vars is not None:
     cmdline_config.add_section('template-vars')
