@@ -1,5 +1,5 @@
-# Lazygal, a lazy satic web gallery generator.
-# Copyright (C) 2007-2010 Alexandre Rossi <alexandre.rossi@gmail.com>
+# Lazygal, a lazy static web gallery generator.
+# Copyright (C) 2007-2012 Alexandre Rossi <alexandre.rossi@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -47,7 +47,7 @@ def get_hg_rev():
 
         last_revs = repo.changelog.parents(repo.dirstate.parents()[0])
         known_tags = repo.tags().items()
-        for tag, rev in repo.tags().items():
+        for tag, rev in known_tags:
             if tag != 'tip':
                 for last_rev in last_revs:
                     if rev == last_rev:
@@ -58,7 +58,7 @@ def get_hg_rev():
         return ''
 
 
-__version__ = '0.7.2'
+__version__ = '0.7.4'
 
 hg_rev = get_hg_rev()
 if hg_rev: __version__ += '+hg' + hg_rev
