@@ -1,5 +1,5 @@
-# Lazygal, a lazy satic web gallery generator.
-# Copyright (C) 2007-2011 Alexandre Rossi <alexandre.rossi@gmail.com>
+# Lazygal, a lazy static web gallery generator.
+# Copyright (C) 2007-2012 Alexandre Rossi <alexandre.rossi@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,9 +16,8 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 
-import os
-import random, time
-import Image, ImageDraw, ImageChops, ImageFilter
+import random
+import Image, ImageChops, ImageFilter
 
 
 class Color:
@@ -143,11 +142,24 @@ class PictureMess:
         self.picture_mess.save(output_file)
 
 
+class PictureTidy(PictureMess):
+
+    THUMB_MAX_ROTATE_ANGLE = 0
+
+
+WEBALBUMPIC_TYPES = {
+    'messy': PictureMess,
+    'tidy' : PictureTidy,
+}
+
+
 if __name__ == '__main__':
     from optparse import OptionParser
 
-    parser = OptionParser();
+    parser = OptionParser()
     parser.add_option("-s", "--seed", type="int", dest="seed")
+    parser.add_option("-t", "--type", dest="type",
+                      action="store_true", default=False)
     parser.add_option("-b", "--background", type="string",
                       dest="color", default="transparent")
     (options, args) = parser.parse_args()
@@ -155,7 +167,10 @@ if __name__ == '__main__':
     if options.seed:
         random.seed(options.seed)
 
-    PictureMess(args[0:], bg=options.color).write('test.png')
+    MultipicRepr = PictureMess
+    if options.type:
+        MultipicRepr = WEBALBUMPIC_TYPES[options.type]
+    MultipicRepr(args[0:], bg=options.color).write('test.png')
 
 
 # vim: ts=4 sw=4 expandtab
