@@ -1,5 +1,5 @@
-# Lazygal, a lazy satic web gallery generator.
-# Copyright (C) 2007-2011 Alexandre Rossi <alexandre.rossi@gmail.com>
+# Lazygal, a lazy static web gallery generator.
+# Copyright (C) 2007-2012 Alexandre Rossi <alexandre.rossi@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -204,6 +204,8 @@ class WebalbumMediaTask(make.GroupTask):
                 self.add_dependency(self.get_original())
 
             self.browse_pages[size_name] = self.get_browse_page(size_name)
+            if self.webgal.album.force_gen_pages:
+                self.browse_pages[size_name].stamp_delete()
 
     def set_next(self, media):
         self.next = media
@@ -271,10 +273,8 @@ class WebalbumVideoTask(WebalbumMediaTask):
 
     def get_resized(self, size_name):
         if not self.webvideo:
-            if self.media.extension == '.webm':
-                self.webvideo = self.get_original()
-            else:
-                self.webvideo = genmedia.WebVideo(self.webgal, self.media)
+            self.webvideo = genmedia.WebVideo(self.webgal, self.media,
+                                              self.webgal.default_size_name)
         return self.webvideo
 
 
@@ -434,6 +434,7 @@ class WebalbumDir(make.FileMakeObject):
         self.subgal_sort_by = self.__parse_sort(self.config.get('webgal', 'sort-subgals'))
 
         self.webalbumpic_bg = self.config.get('webgal', 'webalbumpic-bg')
+        self.webalbumpic_type = self.config.get('webgal', 'webalbumpic-type')
         try:
             self.webalbumpic_size = map(int, self.config.get('webgal', 'webalbumpic-size').split('x'))
             if len(self.webalbumpic_size) != 2:
@@ -441,6 +442,7 @@ class WebalbumDir(make.FileMakeObject):
         except ValueError:
             logging.error(_('Bad syntax for webalbumpic-size.'))
             sys.exit(1)
+        self.keep_gps = self.config.getboolean('webgal', 'keep-gps')
 
     def set_original(self, original=False, orig_base=None, orig_symlink=False):
         self.original = original or orig_symlink
@@ -479,6 +481,8 @@ class WebalbumDir(make.FileMakeObject):
         for size_name in self.browse_sizes:
             page = genpage.WebalbumIndexPage(self, size_name, page_number,
                                              subgals, galleries)
+            if self.album.force_gen_pages:
+                page.stamp_delete()
             self.add_dependency(page)
             pages.append(page)
         self.index_pages.append(pages)
@@ -525,25 +529,26 @@ class WebalbumDir(make.FileMakeObject):
             return False
 
     def rel_path_to_src(self, target_srcdir_path):
-        '''
+        """
         Returns the relative path to go from this directory to
         target_srcdir_path.
-        '''
+        """
         return self.source_dir.rel_path(self.source_dir.path,
                                         target_srcdir_path)
 
     def rel_path(self, path):
-        '''
-        Returns the relative path to go from this directory to the path supplied
-        as argument.
-        '''
+        """
+        Returns the relative path to go from this directory to the path
+        supplied as argument.
+        """
         return os.path.relpath(path, self.path)
 
     def flattening_srcpath(self, srcdir_path):
-        '''
+        """
         Returns the source path in which srcdir_path should flattened, that is
-        the path of the gallery index that will point to srcdir_path's pictures.
-        '''
+        the path of the gallery index that will point to srcdir_path's
+        pictures.
+        """
         if self.should_be_flattened(srcdir_path):
             cur_path = srcdir_path
             while self.should_be_flattened(cur_path):
@@ -660,6 +665,7 @@ class Album:
             logging.getLogger().setLevel(logging.DEBUG)
 
         self.clean_dest = self.config.getboolean('global', 'clean-destination')
+        self.force_gen_pages = self.config.getboolean('global', 'force-gen-pages')
 
         self.tpl_loader = None
 
@@ -725,14 +731,14 @@ class Album:
         logging.info(_('  %sRM %s') % (text, file_path))
 
     def walk(self, top, walked=None):
-        '''
+        """
         This is a wrapper around os.walk() from the standard library:
         - browsing with topdown=False
         - following symbolic links on directories
         - whith barriers in place against walking twice the same directory,
           which may happen when two directory trees have symbolic links to
           each other's contents.
-        '''
+        """
         if walked is None: walked = []
 
         for root, dirs, files in os.walk(top, topdown=False):
@@ -751,9 +757,9 @@ class Album:
             yield root, dirs, files
 
     def generate_default_metadata(self):
-        '''
+        """
         Generate default metada files if no exists.
-        '''
+        """
         logging.debug(_("Generating metadata in %s") % self.source_dir)
 
         for root, dirnames, filenames in self.walk(self.source_dir):
