@@ -1,5 +1,5 @@
-# Lazygal, a lazy satic web gallery generator.
-# Copyright (C) 2007-2011 Alexandre Rossi <alexandre.rossi@gmail.com>
+# Lazygal, a lazy static web gallery generator.
+# Copyright (C) 2007-2012 Alexandre Rossi <alexandre.rossi@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,40 +22,45 @@ import logging
 import zipfile
 
 import make
+import pathutils
 
 
 class MediaOriginal(make.FileCopy):
 
-    def __init__(self, dir, source_media, size_name=None):
+    def __init__(self, dir, source_media):
         self.dir = dir
+        self.source_media = source_media
 
-        dest_name = source_media.filename
-        if size_name:
-            dest_name = self.dir.album._add_size_qualifier(dest_name, size_name)
+        self.filename = source_media.filename
 
-        self.path = os.path.join(self.dir.path, dest_name)
+        self.path = os.path.join(self.dir.path, self.filename)
         make.FileCopy.__init__(self, source_media.path, self.path)
 
+    def get_size(self):
+        return self.source_media.get_size()
+
     def build(self):
-        logging.info("  CP %s" % os.path.basename(self.path))
+        logging.info("  CP %s" % self.filename)
         logging.debug("(%s)" % self.path)
         make.FileCopy.build(self)
 
 
 class SymlinkMediaOriginal(make.FileSymlink):
 
-    def __init__(self, dir, source_media, size_name=None):
+    def __init__(self, dir, source_media):
         self.dir = dir
+        self.source_media = source_media
 
-        dest_name = source_media.filename
-        if size_name:
-            dest_name = self.dir.album._add_size_qualifier(dest_name, size_name)
+        self.filename = source_media.filename
 
-        self.path = os.path.join(self.dir.path, dest_name)
+        self.path = os.path.join(self.dir.path, self.filename)
         make.FileSymlink.__init__(self, source_media.path, self.path)
 
+    def get_size(self):
+        return self.source_media.get_size()
+
     def build(self):
-        logging.info("  SYMLINK %s" % os.path.basename(self.path))
+        logging.info("  SYMLINK %s" % self.filename)
         logging.debug("(%s)" % self.path)
         make.FileSymlink.build(self)
 
@@ -67,15 +72,21 @@ class WebalbumFile(make.FileMakeObject):
         self.dir = dir
         self.path = path
 
-    def rel_path(self, dir):
-        '''
+    def rel_path(self, dir, url=False):
+        """
         Returns the path of the current object relative to the supplied dir
-        object argument.
-        '''
+        object argument. Force forward slashes if url is True.
+        """
+        ret = None
         if dir is None or dir is self.dir:
-            return os.path.basename(self.path)
+            ret = os.path.basename(self.path)
         else:
-            return dir.rel_path(self.path)
+            ret = dir.rel_path(self.path)
+
+        if url:
+            return pathutils.url_path(ret)
+        else:
+            return ret
 
 
 class WebalbumArchive(WebalbumFile):
