@@ -1,5 +1,5 @@
-# Lazygal, a lazy satic web gallery generator.
-# Copyright (C) 2007-2011 Alexandre Rossi <alexandre.rossi@gmail.com>
+# Lazygal, a lazy static web gallery generator.
+# Copyright (C) 2007-2012 Alexandre Rossi <alexandre.rossi@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -41,10 +41,10 @@ class ResizedImage(genfile.WebalbumFile):
     def __init__(self, webgal, source_media, size_name):
         self.webgal = webgal
         self.source_media = source_media
-        path = os.path.join(self.webgal.path,
-               self.webgal._add_size_qualifier(self.source_media.filename,
-                                               size_name,
-                                               self.force_extension))
+        self.filename = self.webgal._add_size_qualifier(self.source_media.filename,
+                                                        size_name,
+                                                        self.force_extension)
+        path = os.path.join(self.webgal.path, self.filename)
         genfile.WebalbumFile.__init__(self, path, webgal)
 
         self.newsizer = self.webgal.newsizers[size_name]
@@ -87,6 +87,10 @@ class ResizedImage(genfile.WebalbumFile):
             self.stamp_build()
 
     def resize(self, im):
+        self.source_media.get_size() # Probe brokenness
+        if self.source_media.broken:
+            raise IOError()
+
         new_size = self.get_size()
 
         im.draft(None, new_size)
@@ -128,6 +132,9 @@ class ImageOtherSize(ResizedImage):
     def get_size(self):
         if self.size is None:
             orig_size = self.source_media.get_size()
+            if self.source_media.broken:
+                return orig_size
+
             if self.get_rotation() in (90, 270, ):
                 # swap coords
                 orig_size = (orig_size[1], orig_size[0], )
@@ -148,8 +155,12 @@ class ImageOtherSize(ResizedImage):
     }
 
     def resize(self, im):
+        self.source_media.get_size() # Probe brokenness
+        if self.source_media.broken:
+            raise IOError()
+
         rotation = self.get_rotation()
-        new_size = self.get_size()
+        self.get_size()
 
         im.draft(None, self.unrotated_size)
         im = im.resize(self.unrotated_size, PILImage.ANTIALIAS)
@@ -183,12 +194,15 @@ class ImageOtherSize(ResizedImage):
             # in a web browser. Fix orientation tag accordingly.
             dest_imgtags['Exif.Image.Orientation'] = 1
 
-        # Those are removed from published pics due to pivacy concerns
-        for tag in self.PRIVATE_IMAGE_TAGS:
-            try:
-                del dest_imgtags[tag]
-            except KeyError:
-                pass
+        # Those are removed from published pics due to pivacy concerns,
+        # unless explicitly told to keep them in. Option to retain GPS
+        # tags can only be set from command line.
+        if not self.webgal.keep_gps:
+            for tag in self.PRIVATE_IMAGE_TAGS:
+                try:
+                    del dest_imgtags[tag]
+                except KeyError:
+                    pass
         try:
             dest_imgtags.write()
         except ValueError, e:
@@ -257,11 +271,13 @@ class WebalbumPicture(make.FileMakeObject):
 
         pics = [thumb.path for thumb in thumbs]
 
+        multipic_repr = eyecandy.WEBALBUMPIC_TYPES[webgal_dir.webalbumpic_type]
+
         # Use 800x600 as a random value to obtain a 4:3 aspect ratio (if
         # thumb size preserves aspect ratio)
-        self.dirpic = eyecandy.PictureMess(pics, md_dirpic_thumb,
-                bg=webgal_dir.webalbumpic_bg,
-                result_size=webgal_dir.webalbumpic_size)
+        self.dirpic = multipic_repr(pics, md_dirpic_thumb,
+                                    bg=webgal_dir.webalbumpic_bg,
+                                    result_size=webgal_dir.webalbumpic_size)
 
     def build(self):
         logging.info(_("  DIRPIC %s") % os.path.basename(self.path))
@@ -274,12 +290,16 @@ class WebalbumPicture(make.FileMakeObject):
 
 class WebVideo(genfile.WebalbumFile):
 
-    def __init__(self, webgal, source_video):
+    def __init__(self, webgal, source_video, size_name):
         self.webgal = webgal
         self.source_video = source_video
-        path = os.path.join(self.webgal.path, source_video.name + '.webm')
+        self.filename = self.webgal._add_size_qualifier(self.source_video.filename,
+                                                        size_name, '.webm')
+        path = os.path.join(self.webgal.path, self.filename)
         genfile.WebalbumFile.__init__(self, path, webgal)
 
+        self.newsizer = self.webgal.newsizers[size_name]
+
         self.add_dependency(self.source_video)
 
     def build(self):
@@ -287,12 +307,13 @@ class WebVideo(genfile.WebalbumFile):
         logging.info(_("  TRANSCODE %s") % vid_rel_path)
 
         try:
-            mediautils.WebMTranscoder(self.source_video.path).convert(self.path)
+            width, height = self.newsizer.dest_size(self.source_video.get_size())
+            mediautils.WebMTranscoder(self.source_video.path, width, height).convert(self.path)
         except mediautils.TranscodeError, e:
             logging.error(_("  transcoding %s failed, skipped")\
                           % self.source_video.filename)
             logging.info(str(e))
-            self.source_media.broken = True
+            self.source_video.broken = True
             self.clean_output()
 
 
