@@ -1,5 +1,5 @@
-# Lazygal, a lazy satic web gallery generator.
-# Copyright (C) 2007-2010 Alexandre Rossi <alexandre.rossi@gmail.com>
+# Lazygal, a lazy static web gallery generator.
+# Copyright (C) 2007-2012 Alexandre Rossi <alexandre.rossi@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,17 +18,15 @@
 
 import os
 import posixpath
-import pathutils
 import sys
 import logging
 import urllib
-import locale
 
 import genshi
 
 import make
 import pathutils
-import genfile, genmedia, feeds
+import genfile, feeds
 
 
 class WebalbumPage(genfile.WebalbumFile):
@@ -59,16 +57,16 @@ class WebalbumPage(genfile.WebalbumFile):
         tpl_values.update(self.dir.tpl_vars)
         return tpl_values
 
-    def _gen_other_media_link(self, media, dir=None):
+    def _gen_other_media_link(self, media):
         if media:
             link_vals = {}
 
             link_vals['type'] = media.media.type
 
-            link_vals['link'] = media.browse_pages[self.size_name].rel_path(dir)
+            link_vals['link'] = media.browse_pages[self.size_name].rel_path(self.dir, url=True)
             link_vals['link'] = self.url_quote(link_vals['link'])
 
-            link_vals['thumb'] = media.thumb.rel_path(dir)
+            link_vals['thumb'] = media.thumb.rel_path(self.dir, url=True)
             link_vals['thumb'] = self.url_quote(link_vals['thumb'])
 
             if not media.media.broken:
@@ -164,7 +162,8 @@ class WebalbumBrowsePage(WebalbumPage):
         self.media = self.webalbum_media.media
         WebalbumPage.__init__(self, dir, size_name, self.media.name)
 
-        self.add_dependency(self.webalbum_media.resized[size_name])
+        self.browse_media = self.webalbum_media.resized[size_name]
+        self.add_dependency(self.browse_media)
         if webalbum_media.original:
             self.add_dependency(self.webalbum_media.original)
 
@@ -209,7 +208,7 @@ class WebalbumBrowsePage(WebalbumPage):
             tpl_values['index_link'] = index_rel_dir + tpl_values['index_link']
 
         tpl_values['osize_links'] = self._get_osize_links(self.media.name)
-        tpl_values['rel_root'] = self.dir.source_dir.rel_root() + '/'
+        tpl_values['rel_root'] = pathutils.url_path(self.dir.source_dir.rel_root()) + '/'
 
         if self.dir.feed is not None:
             tpl_values['feed_url'] = os.path.relpath(self.dir.feed.path,
@@ -221,10 +220,10 @@ class WebalbumBrowsePage(WebalbumPage):
 
         if self.dir.original:
             if self.dir.orig_base:
-                tpl_values['original_link'] = os.path.join(\
-                    self.dir.source_dir.rel_root(),
+                tpl_values['original_link'] = posixpath.join(\
+                    pathutils.url_path(self.dir.source_dir.rel_root()),
                     self.dir.orig_base,
-                    self.dir.source_dir.strip_root(),
+                    pathutils.url_path(self.dir.source_dir.strip_root()),
                     self.media.filename)
             else:
                 tpl_values['original_link'] = self.media.filename
@@ -243,25 +242,16 @@ class WebalbumImagePage(WebalbumBrowsePage):
         self.image = self.media
 
     def add_extra_vals(self, tpl_values):
-        tpl_values['img_src'] = self._add_size_qualifier(self.image.filename,
-                                                         self.size_name)
+        tpl_values['img_src'] = self.browse_media.filename
         tpl_values['img_src'] = self.url_quote(tpl_values['img_src'])
 
         tpl_values['image_name'] = self.image.filename
 
-        browse_image_path = os.path.join(self.dir.path,
-                                         self._add_size_qualifier(\
-                                           self.image.filename, self.size_name))
-
-        if not self.image.broken:
-            tpl_values['img_width'],\
-            tpl_values['img_height'] = self.image.get_size(browse_image_path)
+        tpl_values['img_width'], tpl_values['img_height'] = self.webalbum_media.resized[self.size_name].get_size()
 
         img_date = self.image.get_date_taken()
-        # strftime does not work with unicode...
-        time_format = _("on %d/%m/%Y at %H:%M").encode(locale.getpreferredencoding())
-        time_str = img_date.strftime(time_format)
-        tpl_values['image_date'] = time_str.decode(locale.getpreferredencoding())
+        tpl_values['image_date'] = img_date.strftime(_("on %d/%m/%Y at %H:%M"))
+        tpl_values['image_datetime'] = img_date
 
         image_info = self.image.info()
         if image_info:
@@ -288,7 +278,7 @@ class WebalbumVideoPage(WebalbumBrowsePage):
         self.video = self.media
 
     def add_extra_vals(self, tpl_values):
-        tpl_values['video_src'] = self.video.name + '.webm'
+        tpl_values['video_src'] = self.browse_media.filename
         tpl_values['video_src'] = self.url_quote(tpl_values['video_src'])
 
 
@@ -312,12 +302,15 @@ class WebalbumIndexPage(WebalbumPage):
             self.add_dependency(dir.source_dir)
             self.add_dependency(dir.sort_task)
 
-            for media in medias:
-                if media.thumb: self.add_dependency(media.thumb)
-                self.add_dependency(media.browse_pages[size_name])
-                # Ensure dir depends on browse page (usefull for cleanup checks
-                # when dir is flattenend).
-                dir.add_dependency(media.browse_pages[size_name])
+            if size_name in dir.browse_sizes:
+                for media in medias:
+                    if media.thumb: self.add_dependency(media.thumb)
+                    self.add_dependency(media.browse_pages[size_name])
+                    # Ensure dir depends on browse page (usefull for cleanup
+                    # checks when dir is flattenend).
+                    dir.add_dependency(media.browse_pages[size_name])
+            else:
+                logging.warning(_("  Size '%s' is not available in '%s' due to configuration: medias won't be shown on index.") % (size_name, dir.path))
 
             if self.dir.dirzip is not None:
                 self.add_dependency(self.dir.dirzip)
@@ -328,9 +321,9 @@ class WebalbumIndexPage(WebalbumPage):
         self.set_template('dirindex.thtml')
 
     def _get_paginated_name(self, page_number=None):
-        if page_number == None:
+        if page_number is None:
             page_number = self.page_number
-        assert page_number != None
+        assert page_number is not None
 
         if page_number < 1:
             return WebalbumIndexPage.FILENAME_BASE_STRING
@@ -375,7 +368,7 @@ class WebalbumIndexPage(WebalbumPage):
             dir_info['album_name'] = dir.source_dir.human_name
 
         if dir.dirzip:
-            archive_rel_path = dir.dirzip.rel_path(self.dir)
+            archive_rel_path = dir.dirzip.rel_path(self.dir, url=True)
             dir_info['dirzip'] = self.url_quote(archive_rel_path)
             dir_info['dirzip_size'] = self.format_filesize(dir.dirzip.size())
 
@@ -392,10 +385,10 @@ class WebalbumIndexPage(WebalbumPage):
         subgal_links = []
         for subgal in self.dir.subgals:
             dir_info = self._get_dir_info(subgal)
-            dir_info['link'] = '/'.join([subgal.source_dir.name,
-                                         self._get_related_index_fn()])
+            dir_info['link'] = posixpath.join(subgal.source_dir.name,
+                                              self._get_related_index_fn())
             dir_info['link'] = self.url_quote(dir_info['link'])
-            dir_info['album_picture'] = os.path.join(subgal.source_dir.name,
+            dir_info['album_picture'] = posixpath.join(subgal.source_dir.name,
                                             self.dir.get_webalbumpic_filename())
             dir_info['album_picture'] = self.url_quote(dir_info['album_picture'])
             subgal_links.append(dir_info)
@@ -426,14 +419,19 @@ class WebalbumIndexPage(WebalbumPage):
         values['medias'] = []
         for subdir, medias in self.galleries:
             info = self._get_dir_info(subdir)
-            media_links = [self._gen_other_media_link(media, subdir)
-                           for media in medias]
+            if self.size_name in subdir.browse_sizes:
+                media_links = [self._gen_other_media_link(media)
+                               for media in medias]
+            else:
+                # This happens when this dir index size is not available in the
+                # subdir.
+                media_links = []
             values['medias'].append((info, media_links, ))
 
         values.update(self._get_dir_info())
 
-        values['rel_root'] = self.dir.source_dir.rel_root() + '/'
-        values['rel_path'] = self.dir.source_dir.strip_root()
+        values['rel_root'] = pathutils.url_path(self.dir.source_dir.rel_root()) + '/'
+        values['rel_path'] = pathutils.url_path(self.dir.source_dir.strip_root())
 
         if self.dir.feed is not None:
             values['feed_url'] = os.path.relpath(self.dir.feed.path,
