@@ -1,5 +1,5 @@
-# Lazygal, a lazy satic web gallery generator.
-# Copyright (C) 2010-2011 Alexandre Rossi <alexandre.rossi@gmail.com>
+# Lazygal, a lazy static web gallery generator.
+# Copyright (C) 2010-2012 Alexandre Rossi <alexandre.rossi@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -45,6 +45,7 @@ def signal_handler(signum, frame):
 
 
 def gobject_init():
+    global gobjects_threads_init
     gobject.threads_init()
     gobjects_threads_init = True
     signal.signal(signal.SIGINT, signal_handler)
@@ -206,7 +207,8 @@ class GstVideoReader(GstVideoOpener):
 
 class GstVideoTranscoder(GstVideoReader):
 
-    def __init__(self, mediapath, audiocodec, videocodec, muxer):
+    def __init__(self, mediapath, audiocodec, videocodec, muxer,
+                 width=None, height=None):
         super(GstVideoTranscoder, self).__init__(mediapath)
 
         # Audio
@@ -223,9 +225,22 @@ class GstVideoTranscoder(GstVideoReader):
         # Video
         self.decode_video()
 
+        self.videoscale = gst.element_factory_make('videoscale', 'videoscale')
+        self.videoscale.set_property('method', 'bilinear')
+        self.pipeline.add(self.videoscale)
+        self.ff.link(self.videoscale)
+        caps_str = "video/x-raw-yuv"
+        if width is not None and height is not None:
+            caps_str += ", width=%d, height=%d" % (width, height)
+        caps = gst.Caps(caps_str)
+        self.caps_filter = gst.element_factory_make("capsfilter", "filter")
+        self.caps_filter.set_property("caps", caps)
+        self.pipeline.add(self.caps_filter)
+        self.videoscale.link(self.caps_filter)
+
         self.videoenc = gst.element_factory_make(videocodec, 'videoenc')
         self.pipeline.add(self.videoenc)
-        self.ff.link(self.videoenc)
+        self.caps_filter.link(self.videoenc)
 
         voqueue = gst.element_factory_make("queue")
         self.pipeline.add(voqueue)
@@ -270,7 +285,7 @@ class OggTheoraTranscoder(GstVideoTranscoder):
 
 class WebMTranscoder(GstVideoTranscoder):
 
-    def __init__(self, mediapath):
+    def __init__(self, mediapath, width=None, height=None):
         # Working pipeline
         # gst-launch-0.10 filesrc location=oldfile.ext ! decodebin name=demux !
         # queue ! ffmpegcolorspace ! vp8enc ! webmmux name=mux ! filesink
@@ -281,7 +296,8 @@ class WebMTranscoder(GstVideoTranscoder):
         # ! )
 
         super(WebMTranscoder, self).__init__(mediapath,
-                                             'vorbisenc', 'vp8enc', 'webmmux')
+                                             'vorbisenc', 'vp8enc', 'webmmux',
+                                             width, height)
 
         self.videoenc.set_property('quality', 7)
 
