@@ -1,5 +1,5 @@
-# Lazygal, a lazy satic web gallery generator.
-# Copyright (C) 2011 Alexandre Rossi <alexandre.rossi@gmail.com>
+# Lazygal, a lazy static web gallery generator.
+# Copyright (C) 2011-2012 Alexandre Rossi <alexandre.rossi@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -54,10 +54,10 @@ class TestGenerators(LazygalTestGen):
             self.assertTrue(os.path.isfile(os.path.join(dest_subgal_path, fn)))
 
     def test_filecleanup(self):
-        '''
+        """
         Files that are not part of what was generated or updated shall be
         spotted.
-        '''
+        """
         pics = [ 'img%d.jpg' % i for i in range(0, 8)]
         source_subgal = self.setup_subgal('subgal', pics)
 
@@ -230,9 +230,9 @@ class TestSpecialGens(LazygalTestGen):
         self.dest_path = os.path.join(self.tmpdir, 'dst')
 
     def test_paginate(self):
-        '''
+        """
         It shall be possible to split big galleries on mutiple index pages.
-        '''
+        """
         config = lazygal.config.LazygalConfig()
         config.set('webgal', 'thumbs-per-page', 4)
         self.setup_album(config)
@@ -269,11 +269,11 @@ class TestSpecialGens(LazygalTestGen):
 
     @skip(not has_symlinks(), 'symlinks not supported on platform')
     def test_dir_symlink(self):
-        '''
+        """
         The generator should follow symlinks on directories, but should not get
         stuck in infinite recursion if two distinct directory trees have
         symbolic links to each other.
-        '''
+        """
         self.setup_album()
 
         pics = [ 'img%d.jpg' % i for i in range(0, 2)]
@@ -325,8 +325,10 @@ class TestSorting(LazygalTestGen):
         super(TestSorting, self).setUp(False)
         self.dest_path = os.path.join(self.tmpdir, 'dst')
 
-    def __setup_pics(self):
-        subgal_path = os.path.join(self.source_dir, 'subgal')
+    def __setup_pics(self, subgal_name=None):
+        if subgal_name is None:
+            subgal_name = 'subgal'
+        subgal_path = os.path.join(self.source_dir, subgal_name)
         os.mkdir(subgal_path)
 
         pics = ['4-december.jpg', '6-january.jpg', '1-february.jpg', '3-june.jpg', '5-august.jpg']
@@ -346,9 +348,10 @@ class TestSorting(LazygalTestGen):
         return subgal_path, pics
 
     def test_sortbyexif(self):
-        '''
-        It shall be possible to sort images in a gallery according to EXIF date.
-        '''
+        """
+        It shall be possible to sort images in a gallery according to EXIF
+        date.
+        """
         config = lazygal.config.LazygalConfig()
         config.set('webgal', 'sort-medias', 'exif')
         self.setup_album(config)
@@ -363,10 +366,10 @@ class TestSorting(LazygalTestGen):
                          [u'6-january.jpg', u'1-february.jpg', u'3-june.jpg', u'5-august.jpg', u'4-december.jpg'])
 
     def test_sortbyexif_galsplit(self):
-        '''
+        """
         It shall be possible to sort images in galleries split on multiple
         pages according to EXIF date.
-        '''
+        """
         config = lazygal.config.LazygalConfig()
         config.set('webgal', 'sort-medias', 'exif')
         config.set('webgal', 'thumbs-per-page', 3)
@@ -391,9 +394,9 @@ class TestSorting(LazygalTestGen):
                          [u'5-august.jpg', u'4-december.jpg'])
 
     def test_sortbyfilename(self):
-        '''
+        """
         It shall be possible to sort images in a gallery by filename.
-        '''
+        """
         config = lazygal.config.LazygalConfig()
         config.set('webgal', 'sort-medias', 'filename')
         self.setup_album(config)
@@ -408,10 +411,10 @@ class TestSorting(LazygalTestGen):
                          [u'1-february.jpg', u'3-june.jpg', u'4-december.jpg', u'5-august.jpg', u'6-january.jpg'])
 
     def test_sortbyfilename_galsplit(self):
-        '''
+        """
         It shall be possible to sort images in galleries split on multiple
         pages by filename.
-        '''
+        """
         config = lazygal.config.LazygalConfig()
         config.set('webgal', 'sort-medias', 'filename')
         config.set('webgal', 'thumbs-per-page', 3)
@@ -435,6 +438,36 @@ class TestSorting(LazygalTestGen):
         self.assertEqual([media.media.filename for media in page_medias],
                          [u'5-august.jpg', u'6-january.jpg'])
 
+    def test_sortsubgals_dirnamereverse(self):
+        """
+        It shall be possible to sort sub-galleries accoring to the directory
+        name.
+        """
+        config = lazygal.config.LazygalConfig()
+        config.set('webgal', 'sort-subgals', 'dirname:reverse')
+        self.setup_album(config)
+
+        subgal_names = ('john', '2012_Trip', 'albert', '1999_Christmas', 'joe', )
+        subgals_src = []
+        subgals_dst = []
+        for subgal_name in subgal_names:
+            path, pics = self.__setup_pics(subgal_name)
+            src = Directory(path, [], pics, self.album)
+            dst = WebalbumDir(src, [], self.album,
+                              os.path.join(self.dest_path, subgal_name))
+            subgals_src.append(src)
+            subgals_dst.append(dst)
+
+        src_dir = Directory(self.source_dir, subgals_src, [], self.album)
+        dest_subgal = WebalbumDir(src_dir, subgals_dst, self.album, self.dest_path)
+
+        dest_subgal.sort_task.make()
+
+        self.assertEqual(
+            [subgal.source_dir.name for subgal in dest_subgal.subgals],
+            [u'john', u'joe', u'albert', u'2012_Trip', u'1999_Christmas']
+        )
+
 
 if __name__ == '__main__':
     unittest.main()
